@@ -1,9 +1,9 @@
-#ifndef __MOBIUS_CRYPT_CIPHER_BASE_H__
-#define __MOBIUS_CRYPT_CIPHER_BASE_H__
+#ifndef MOBIUS_CRYPT_CIPHER_BASE_H
+#define MOBIUS_CRYPT_CIPHER_BASE_H
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -18,6 +18,9 @@
 // You should have received a copy of the GNU General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+#include <mobius/bytearray.h>
+#include <cstddef>
+
 namespace mobius
 {
 namespace crypt
@@ -30,14 +33,17 @@ class cipher_base
 {
 public:
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  //! \brief virtual destructor for safe inheritance
+  //! \brief Virtual destructor for safe inheritance
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   virtual ~cipher_base () = default;
 
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  // abstract methods
+  // Abstract methods
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  virtual mobius::bytearray encrypt (const mobius::bytearray&) = 0;
+  virtual mobius::bytearray decrypt (const mobius::bytearray&) = 0;
   virtual void reset () = 0;
+  virtual std::size_t get_block_size () const noexcept = 0;
 };
 
 } // namespace crypt
