@@ -1,9 +1,9 @@
-#ifndef __MOBIUS_DATETIME_CONV_ISO_STRING_H__
-#define __MOBIUS_DATETIME_CONV_ISO_STRING_H__
+#ifndef MOBIUS_DATETIME_CONV_ISO_STRING_H
+#define MOBIUS_DATETIME_CONV_ISO_STRING_H
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -27,10 +27,10 @@ namespace mobius
 {
 namespace datetime
 {
-
-const std::string date_to_iso_string (const date&);
-const std::string time_to_iso_string (const time&);
-const std::string datetime_to_iso_string (const datetime&);
+std::string date_to_iso_string (const date&);
+std::string time_to_iso_string (const time&);
+std::string datetime_to_iso_string (const datetime&);
+datetime new_datetime_from_iso_string (const std::string&);
 
 } // namespace datetime
 } // namespace mobius
