@@ -1,9 +1,9 @@
-#ifndef __MOBIUS_IMAGEFILE_EWF_WRITER_IMPL_H__
-#define __MOBIUS_IMAGEFILE_EWF_WRITER_IMPL_H__
+#ifndef MOBIUS_IMAGEFILE_EWF_WRITER_IMPL_H
+#define MOBIUS_IMAGEFILE_EWF_WRITER_IMPL_H
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -20,6 +20,7 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 #include <mobius/imagefile/ewf/imagefile_impl.h>
 #include <mobius/imagefile/ewf/segment_writer.h>
+#include <mobius/imagefile/segment_array.h>
 #include <mobius/io/writer_impl_base.h>
 #include <mobius/crypt/hash_md5.h>
 #include <vector>
@@ -31,48 +32,48 @@ namespace imagefile
 namespace ewf
 {
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief ewf imagefile writer implementation class
+//! \brief EWF imagefile writer implementation class
 //! \author Eduardo Aguiar
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 class writer_impl : public mobius::io::writer_impl_base
 {
 public:
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  // constructors and destructor
+  // Constructors and destructor
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   explicit writer_impl (const imagefile_impl&);
-  writer_impl (const writer_impl&) = default;
-  writer_impl (writer_impl&&) = default;
+  writer_impl (const writer_impl&) = delete;
+  writer_impl (writer_impl&&) = delete;
   ~writer_impl ();
 
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  // assignment operators
+  // Assignment operators
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  writer_impl& operator= (const writer_impl&) = default;
-  writer_impl& operator= (writer_impl&&) = default;
+  writer_impl& operator= (const writer_impl&) = delete;
+  writer_impl& operator= (writer_impl&&) = delete;
 
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  // virtual methods
+  // Virtual methods
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  virtual size_type write (const mobius::bytearray&) override;
-  virtual void seek (offset_type, whence_type = whence_type::beginning) override;
-  virtual void flush () override;
+  size_type write (const mobius::bytearray&) override;
+  void seek (offset_type, whence_type = whence_type::beginning) override;
+  void flush () override;
 
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  //! \brief check if writer is seekable
+  //! \brief Check if writer is seekable
   //! \return true/false
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  virtual bool
+  bool
   is_seekable () const override
   {
     return false;
   }
 
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  //! \brief get current write position
+  //! \brief Get current write position
   //! \return write position in bytes from the beginning of data
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  virtual offset_type
+  offset_type
   tell () const override
   {
     return size_;
@@ -84,20 +85,19 @@ private:
   size_type sector_size_ = 512;         // sector size in bytes
   std::uint8_t compression_level_ = 0;  // compression level (0 - none, 1 - fast, 9 - best)
 
-  size_type segment_number_ = 1;        // segment index, starting from 1
   size_type size_ = 0;                  // imagefile size in bytes
-  std::string url_prefix_;              // URL prefix of segment files
-  std::string url_extension_;           // URL next extension of segment file
+  segment_array segments_;
 
-  segment_writer segment_writer_;       // current segment writer
   std::vector <segment_writer> segment_writer_list_;
+  mobius::bytearray guid_;              // imagefile GUID
   mobius::crypt::hash_md5 hash_;        // hash function for data written
 
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  // private prototypes
+  // Private prototypes
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  const std::string _get_next_extension (const std::string&) const;
-  void _new_segment_writer ();
+  std::string _get_next_extension (const std::string&) const;
+  segment_writer& _new_segment_writer ();
+  segment_writer& _get_current_segment_writer ();
 };
 
 } // namespace ewf
