@@ -89,7 +89,7 @@ public:
   std::string
   get_type () const
   {
-    return static_cast <std::string> (evidence_.get_attribute ("type"));
+    return evidence_.get_attribute <std::string> ("type");
   }
 
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -99,7 +99,7 @@ public:
   std::string
   get_value () const
   {
-    return static_cast <std::string> (evidence_.get_attribute ("value"));
+    return evidence_.get_attribute <std::string> ("value");
   }
 
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -109,7 +109,7 @@ public:
   std::string
   get_description () const
   {
-    return static_cast <std::string> (evidence_.get_attribute ("description"));
+    return evidence_.get_attribute <std::string> ("description");
   }
 
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -129,7 +129,7 @@ public:
   std::string
   get_password () const
   {
-    return static_cast <std::string> (evidence_.get_attribute ("password"));
+    return evidence_.get_attribute <std::string> ("password");
   }
 
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -158,7 +158,7 @@ public:
   mobius::pod::map
   get_metadata () const
   {
-    return static_cast <mobius::pod::map> (evidence_.get_attribute ("metadata", mobius::pod::map ()));
+    return evidence_.get_attribute ("metadata", mobius::pod::map ());
   }
 
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
